// Copyright (c) 2010,2012 GeometryFactory Sarl (France).
// All rights reserved.
//
// This file is part of CGAL (www.cgal.org).
//
// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Mesh_3/include/CGAL/Mesh_3/squared_distance_Point_3_Triangle_3.h $
// $Id: squared_distance_Point_3_Triangle_3.h 5deb509 2021-04-12T14:42:44+02:00 Mael Rouxel-Labbé
// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
//
//
// Author(s)     : Laurent Rineau
//

#ifndef CGAL_SQUARED_DISTANCE_POINT_3_TRIANGLE_3_H
#define CGAL_SQUARED_DISTANCE_POINT_3_TRIANGLE_3_H

#include <CGAL/license/Mesh_3.h>

#include <CGAL/Distance_3/Point_3_Triangle_3.h>

#endif // CGAL_SQUARED_DISTANCE_POINT_3_TRIANGLE_3_H
